@@ -1,15 +1,16 @@
 /* cmake.h.in. Creates cmake.h during a cmake run */
 
-#define L10N                                           // Localization complete.
+/* Product identification */
+#define PRODUCT_TASKWARRIOR 1
 
 /* Package information */
 #define PACKAGE           "task"
-#define VERSION           "2.2.0"
+#define VERSION           "2.3.0"
 #define PACKAGE_BUGREPORT "support@taskwarrior.org"
 #define PACKAGE_NAME      "task"
 #define PACKAGE_TARNAME   "task"
-#define PACKAGE_VERSION   "2.2.0"
-#define PACKAGE_STRING    "task 2.2.0"
+#define PACKAGE_VERSION   "2.3.0"
+#define PACKAGE_STRING    "task 2.3.0"
 
 /* Installation details */
 #define TASK_RCDIR "/usr/local/share/doc/task/rc"
@@ -18,15 +19,16 @@
 #define PACKAGE_LANGUAGE  1
 #define LANGUAGE_EN_US 1
 #define LANGUAGE_ES_ES 2
-#define LANGUAGE_DE_DE 3
 #define LANGUAGE_FR_FR 4
+#define LANGUAGE_DE_DE 3
+#define LANGUAGE_IT_IT 5
 
 /* git information */
 #define HAVE_COMMIT
 
 /* cmake information */
 #define HAVE_CMAKE
-#define CMAKE_VERSION "2.8.9"
+#define CMAKE_VERSION "2.8.11.1"
 
 /* Compiling platform */
 /* #undef LINUX */
@@ -37,31 +39,37 @@
 /* #undef NETBSD */
 /* #undef HAIKU */
 /* #undef SOLARIS */
+/* #undef KFREEBSD */
+/* #undef GNUHURD */
 /* #undef UNKNOWN */
 
+/* Found the GnuTLS library */
+#define HAVE_LIBGNUTLS
+
+/* Found the Readline library */
+/* #undef HAVE_READLINE */
+
 /* Found the pthread library */
 /* #undef HAVE_LIBPTHREAD */
 
-/* Found the readline library */
-/* #undef HAVE_READLINE */
-/* #undef HAVE_LIBREADLINE */
-
-/* Found random */
-#define HAVE_RANDOM
-
-/* Found srandom */
-#define HAVE_SRANDOM
-
 /* Found tm_gmtoff */
 #define HAVE_TM_GMTOFF
 
 /* Found timegm */
 #define HAVE_TIMEGM
 
-/* Found the uuid library */
-#define HAVE_UUID
+/* Found st.st_birthtime struct member */
+#define HAVE_ST_BIRTHTIME
+
+/* Found get_current_dir_name */
+/* #undef HAVE_GET_CURRENT_DIR_NAME */
+
+/* Found uuid_unparse_lower in the uuid library */
 #define HAVE_UUID_UNPARSE_LOWER
 
+/* Found wordexp.h */
+#define HAVE_WORDEXP
+
 /* Undefine this to eliminate the execute command */
 #define HAVE_EXECUTE 1
 
