@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////////////////////////
 // taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006-2014, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +25,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <stdlib.h>
 #include <Context.h>
 #include <ColScheduled.h>
@@ -42,12 +41,6 @@ ColumnScheduled::ColumnScheduled ()
 {
   _name      = "scheduled";
   _label     = STRING_COLUMN_LABEL_SCHED;
-
-  _styles.push_back ("countdown");
-
-  Date now;
-  now += 125;
-  _examples.push_back (Duration (now - Date ()).formatCompact ());
 }
 
 ////////////////////////////////////////////////////////////////////////////////
